NsfwClassification enum

Classification category for NSFW detection results.

Inheritance
Available extensions

Values

safe → const NsfwClassification

Content is considered safe (score < 0.4).

questionable → const NsfwClassification

Content is borderline (score >= 0.4 and < 0.7).

nsfw → const NsfwClassification

Content is considered NSFW (score >= 0.7).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NsfwClassification>
A constant List of the values in this enum, in order of their declaration.