VggMean class

VggMean class defines the mean values for each channel used in the VGG model.

Constructors

VggMean()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

blue → const double
Mean value for the blue channel
green → const double
Mean value for the green channel
red → const double
Mean value for the red channel